pub trait FixedWireSize {
const WIRE_SIZE: usize;
}Expand description
Marker trait for types with a fixed wire size in MySQL binary protocol.
This trait is only implemented for types that have a guaranteed fixed size
on the wire. Native integer types like i64 are NOT implemented because
MySQL uses little-endian encoding, which differs from native byte order on
big-endian platforms.
Use zerocopy’s little-endian types instead:
zerocopy::little_endian::I16instead ofi16zerocopy::little_endian::I32instead ofi32zerocopy::little_endian::I64instead ofi64- etc.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.